﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net.Http;
using System.Threading.Tasks;
using System.Web;
using System.Web.Mvc;
using Newtonsoft.Json;
using NewTravelClientMVC.Models;
using NewTravelClientMVC.Models.Security;

namespace NewTravelClientMVC.Controllers
{
    [Authorize]
    public class CartController : Controller
    {
        
        public async Task<ActionResult> Index()
        {                      
            var products = await GetProductsCartAsync();
            return View(products);
        }



        public async Task<ActionResult> CartList()
        {
            if (Security.getCurrentGuid() != null)
            {
                Guid id = Security.getCurrentGuid().Value;
                var cart = await GetCartListByIdAsync(id);
                return View("CartList", cart);
            }
            System.Web.Security.FormsAuthentication.SignOut();
            return RedirectToAction("Login", "Account");
        }



        [HttpGet]
        public async Task<ActionResult> AddToCart(Guid? id)
        {
            if (id != null)
            {               
                var product = await GetProductCartByIdAsync(id.Value);
                return PartialView("_PartialDetail", product);
            }
            return View();
        }

        [HttpPost]
        public ActionResult AddToCart(Guid Id, int quantity)
        {

            if (Security.getCurrentGuid() != null)
            {               
                Cart cart = new Cart();
                cart.ProductId = Id;
                cart.CustomerId = Security.getCurrentGuid().Value;
                cart.Quantity = quantity;
                InsertNewItemCart(cart);

                return RedirectToAction("Index");
            }

            System.Web.Security.FormsAuthentication.SignOut();
            return RedirectToAction("Login", "Account");
        }





        //
        // GET: /Cart/Details/5

        public ActionResult Details(int id)
        {
            return View();
        }

        //
        // GET: /Cart/Create

        public ActionResult Create()
        {
            return View();
        }

        //
        // POST: /Cart/Create

        [HttpPost]
        public ActionResult Create(FormCollection collection)
        {
            try
            {
                // TODO: Add insert logic here

                return RedirectToAction("Index");
            }
            catch
            {
                return View();
            }
        }

        //
        // GET: /Cart/Edit/5

        public ActionResult Edit(int id)
        {
            return View();
        }

        //
        // POST: /Cart/Edit/5

        [HttpPost]
        public ActionResult Edit(int id, FormCollection collection)
        {
            try
            {
                // TODO: Add update logic here

                return RedirectToAction("Index");
            }
            catch
            {
                return View();
            }
        }

        //
        // GET: /Cart/Delete/5

        public ActionResult Delete(Guid id)
        {

            DeleteItemCartById(id);
            return RedirectToAction("CartList");
        }

        //
        // POST: /Cart/Delete/5

        [HttpPost]
        public ActionResult Delete(int id, FormCollection collection)
        {
            try
            {
                // TODO: Add delete logic here

                return RedirectToAction("Index");
            }
            catch
            {
                return View();
            }
        }


        public async Task<List<CartModel>> GetProductsCartAsync()
        {
            using (HttpClient httpClient = new HttpClient())
            {
                return JsonConvert.DeserializeObject<List<CartModel>>(
                 await httpClient.GetStringAsync(WebAddress.ProductsAddress));
            }
        }

        public async Task<List<Cart>> GetCartListByIdAsync(Guid id)
        {
            using (HttpClient httpClient = new HttpClient())
            {
                var address = WebAddress.CartAddress + "/" + id.ToString(); ;
                return JsonConvert.DeserializeObject<List<Cart>>(
                 await httpClient.GetStringAsync(address));
            }
        }

        public async Task<CartModel> GetProductCartByIdAsync(Guid id)
        {
            using (HttpClient httpClient = new HttpClient())
            {
                var address = WebAddress.ProductsCliAddress + "/" + id.ToString();
                var data = await httpClient.GetStringAsync(address);
                return JsonConvert.DeserializeObject<CartModel>(data);
            }
        }

        public HttpResponseMessage InsertNewItemCart(Cart cart)
        {
            var address = WebAddress.CartAddress;
            HttpClient client = new HttpClient();
            return client.PostAsJsonAsync<Cart>(address, cart).Result;
        }





        public HttpResponseMessage DeleteItemCartById(Guid id)
        {
            var address = WebAddress.ProductsCliAddress + "/" + id.ToString(); ;
            HttpClient client = new HttpClient();
            return client.DeleteAsync(address).Result;
                
                //<Guid>(address, id).Result;
            
        }

        public Task<HttpResponseMessage> InsertNewOrder(int product)
        {
            var address = WebAddress.OrdersAddress;
            HttpClient client = new HttpClient();
            return client.PostAsJsonAsync<int>(address, product);
        }
    }
}
