﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net.Http;
using System.Threading.Tasks;
using System.Web;
using System.Web.Mvc;
using Newtonsoft.Json;
using NewTravelAdminMVC.Models;

namespace NewTravelAdminMVC.Controllers
{
    [Authorize]
    public class CustomersController : Controller
    {
        public async Task<ActionResult> Index()
        {
            var customers = await GetCustomersAsync();
            return View(customers);
        }

        public async Task<ActionResult> Details(Guid id)
        {
            var detail = await GetCustomerDetailByIdAsync(id);
            return View(detail);
        }

        public ActionResult Create()
        {
            return View();
        }

        [HttpPost]
        public ActionResult Create(Customer customer)
        {
            try
            {
                if (ModelState.IsValid)
                {
                    InsertNewProduct(customer);
                    return RedirectToAction("Index");
                }
            }
            catch
            {
                return View();
            }
            return View();
        }

        public async Task<ActionResult> Edit(Guid id)
        {
            var customer = await GetCustomerByIdAsync(id);
            return View(customer);
        }

        [HttpPost]
        public ActionResult Edit(Guid id, Customer customer)
        {
            try
            {
                if (ModelState.IsValid)
                {
                    UpdateCustomertById(customer);
                    return RedirectToAction("Index");
                }
            }
            catch
            {
                return View();
            }
            return View();
        }

        public async Task<List<Customer>> GetCustomersAsync()
        {
            using (HttpClient httpClient = new HttpClient())
            {
                var response = await httpClient.GetStringAsync(WebAddress.CustomerAddress);
                return JsonConvert.DeserializeObject<List<Customer>>(response);
            }
        }

        public async Task<Customer> GetCustomerByIdAsync(Guid id)
        {
            using (HttpClient httpClient = new HttpClient())
            {
                var address = WebAddress.CustomerAddress + "/" + id.ToString();
                var response = await httpClient.GetStringAsync(address);
                return JsonConvert.DeserializeObject<Customer>(response);
            }
        }

        public async Task<Customer> GetCustomerDetailByIdAsync(Guid id)
        {
            using (HttpClient httpClient = new HttpClient())
            {
                var address = WebAddress.CustomerAddress + "/" + id.ToString();
                var response = await httpClient.GetStringAsync(address);
                return JsonConvert.DeserializeObject<Customer>(response);
            }
        }

        public HttpResponseMessage InsertNewProduct(Customer customer)
        {
            HttpClient client = new HttpClient();
            return client.PostAsJsonAsync<Customer>(WebAddress.CustomerAddress, customer).Result;
        }

        public HttpResponseMessage UpdateCustomertById(Customer customer)
        {
            var address = WebAddress.CustomerAddress + "/" + customer.CustomerId.ToString();
            HttpClient client = new HttpClient();
            return client.PutAsJsonAsync<Customer>(address, customer).Result;
        }
    }
}
