﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net.Http;
using System.Threading.Tasks;
using System.Web;
using System.Web.Mvc;
using Newtonsoft.Json;
using NewTravelAdminMVC.Models;

namespace NewTravelAdminMVC.Controllers
{
    [Authorize]
    public class EmployeesController : Controller
    {
        public async Task<ActionResult> Index()
        {
            var emp = await GetEmployeesAsync();
            var orderEmp = emp.OrderBy(m => m.Surname).ThenBy(m => m.Name).ToList();
            return View(orderEmp);
        }

        public ActionResult Details(Guid id)
        {
            //TODO Això ha de fer alguna cosa més
            return View();
        }

        public async Task<ActionResult> Create()
        {
            //var vehicleType = await GetVehicleCategoriesAsync();
            //var filterVehicleType = vehicleType.Where(m => m.Active == true).ToList();
            //ViewBag.vehicleType = filterVehicleType;

            var vehicleCategory = await GetVehicleCategoriesAsync();
            ViewBag.vehicleCategory = vehicleCategory;

            var employeeProfiles = SecurityProfiles.getSecurityProfiles();
            ViewBag.Profile = employeeProfiles;


            return View();
        }

        //
        // POST: /Employees/Create

        [HttpPost]
        public ActionResult Create(Employee employee, Guid[] VehicleCategories)
        {
            try
            {
                if (ModelState.IsValid)
                {

                    if (VehicleCategories != null && employee.Profile > 2 && employee.Profile < 8)
                    {
                        if (employee.Driver.VehicleCategories == null)
                            employee.Driver.VehicleCategories = new List<VehicleCategory>();
                        foreach (Guid category in VehicleCategories)
                        {
                            employee.Driver.VehicleCategories.Add(new VehicleCategory() { VehicleCategoryId = category });
                        }
                    }
                    InsertNewEmployee(employee);
                    return RedirectToAction("Index");
                }               
            }
            catch
            {
                return View();
            }
            return View();
        }

        public async Task<ActionResult> Edit(Guid id)
        {
            var employee = await GetEmployeeByIdAsync(id);
            
            
            var vehicleCategory = await GetVehicleCategoriesAsync();
            ViewBag.vehicleCategory = vehicleCategory;


            var employeeProfiles = SecurityProfiles.getSecurityProfiles(employee.Profile);
            ViewBag.Profile = employeeProfiles;
           
            return View(employee);
        }


        [HttpPost]
        public ActionResult Edit(Guid id, Employee employee, Guid [] VehicleCategories)
        {
            try
            {
                if (ModelState.IsValid)
                {
                    if (VehicleCategories != null && employee.Profile > 2 && employee.Profile < 8)
                    {
                        if (employee.Driver.VehicleCategories == null)
                            employee.Driver.VehicleCategories = new List<VehicleCategory>();
                        foreach (Guid category in VehicleCategories)
                        {
                            employee.Driver.VehicleCategories.Add(new VehicleCategory() { VehicleCategoryId = category });
                        }
                    }

                    UpdateEmployeeById(employee);
                    return RedirectToAction("Index");
                }                
            }
            catch (Exception ex)
            {
                var ss = ex.Message;
                var errVehicleCategory = GetVehicleCategoriesAsync().Result;
                ViewBag.vehicleCategory = errVehicleCategory;
                var errEmployeeProfiles = SecurityProfiles.getSecurityProfiles(employee.Profile);
                ViewBag.Profile = errEmployeeProfiles;

                return View();
            }

            var vehicleCategory = GetVehicleCategoriesAsync().Result;
            ViewBag.vehicleCategory = vehicleCategory;
            var employeeProfiles = SecurityProfiles.getSecurityProfiles(employee.Profile);
            ViewBag.Profile = employeeProfiles;

            return View();
        }             

        #region WebAPI Access Methods

        public async Task<List<Employee>> GetEmployeesAsync()
        {
            using (HttpClient httpClient = new HttpClient())
            {
                var response = await httpClient.GetStringAsync(WebAddress.EmployeesAddress);
                return JsonConvert.DeserializeObject<List<Employee>>(response);               
            }
        }

        public async Task<Employee> GetEmployeeByIdAsync(Guid id)
        {
            using (HttpClient httpClient = new HttpClient())
            {
                var address = WebAddress.EmployeesAddress + "/" + id.ToString();
                var response = await httpClient.GetStringAsync(address);
                return JsonConvert.DeserializeObject<Employee>(response);
            }
        }

        public HttpResponseMessage InsertNewEmployee(Employee employee)
        {
            var address = WebAddress.EmployeesAddress;
            HttpClient client = new HttpClient();
            return client.PostAsJsonAsync<Employee>(address, employee).Result;
        }

        public HttpResponseMessage UpdateEmployeeById(Employee employee)
        {
            var address = WebAddress.EmployeesAddress + "/" + employee.EmployeeId.ToString();
            HttpClient client = new HttpClient();
            return client.PutAsJsonAsync<Employee>(address, employee).Result;
        }

        public async Task<List<VehicleCategory>> GetVehicleCategoriesAsync()
        {
            using (HttpClient httpClient = new HttpClient())
            {
                return JsonConvert.DeserializeObject<List<VehicleCategory>>(
                 await httpClient.GetStringAsync(WebAddress.VehicleCategoryAddress));
            }
        }

        #endregion
    }

}
