﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net.Http;
using System.Threading.Tasks;
using System.Web;
using System.Web.Mvc;
using Newtonsoft.Json;
using NewTravelAdminMVC.Models;

namespace NewTravelAdminMVC.Controllers
{
    [Authorize]
    public class ProductsController : Controller
    {       

        public async Task<ActionResult> Index()
        {
            var Products = await GetProductsAsync();           
            return View(Products);
        }

        public async Task<ActionResult> Details(Guid id)
        {
            var detail = await GetProductDetailsByIdAsync(id);
            return View(detail);
        }

        public ActionResult Create()
        {
            return View();
        }

        [HttpPost]
        public ActionResult Create(Product product)
        {
            try
            {
                if (ModelState.IsValid)
                {
                    var newProduct = InsertNewProduct(product);
                    Task.WaitAll(newProduct);
                    return RedirectToAction("Index");
                }
            }
            catch
            {
                return View();
            }
            return View();
        }

        public async Task<ActionResult> Edit(Guid id)
        {
            var Products = await GetProductByIdAsync(id);
            return View(Products);            
        }

        [HttpPost]
        public ActionResult Edit(Product product)
        {
            try
            {
                if (ModelState.IsValid)
                {
                    var Update = UpdateProductById(product);
                    Task.WaitAll(Update);
                    return RedirectToAction("Index");
                }
            }
            catch 
            {
                return View();
            }
            return View();
        }

        [HttpPost]
        public ActionResult Delete(int id, FormCollection collection)
        {
            try
            {
                return RedirectToAction("Index");
            }
            catch
            {
                return View();
            }
        }

        #region API Calls Methods

        public async Task<List<Product>> GetProductsAsync()
        {
            using (HttpClient httpClient = new HttpClient())
            {
                return JsonConvert.DeserializeObject<List<Product>>(
                 await httpClient.GetStringAsync(WebAddress.ProductAddress));
            }
        }

        public async Task<Product> GetProductByIdAsync(Guid id)
        {
            using (HttpClient httpClient = new HttpClient())
            {
                var address = WebAddress.ProductAddress + "/" + id.ToString();
                var JsonProducte = await httpClient.GetStringAsync(address);
                return JsonConvert.DeserializeObject<Product>(JsonProducte);                
            }
        }

        public Task<HttpResponseMessage> InsertNewProduct(Product product)
        {
            var address = WebAddress.ProductAddress;
            HttpClient client = new HttpClient();
            return client.PostAsJsonAsync<Product>(address, product);
        }
        
        public Task <HttpResponseMessage> UpdateProductById(Product product)
        {
            var address = WebAddress.ProductAddress + "/" + product.ProductId.ToString();
            HttpClient client = new HttpClient();
            return client.PutAsJsonAsync<Product> (address, product);
            
        }

        public async Task<Product> GetProductDetailsByIdAsync(Guid id)
        {
            using (HttpClient httpClient = new HttpClient())
            {
                var address = WebAddress.ProductDetailsAddress + "/" + id.ToString();
                return JsonConvert.DeserializeObject<Product>(
                 await httpClient.GetStringAsync(address));
            }
        }

        #endregion
    }
}
