﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net.Http;
using System.Threading.Tasks;
using System.Web;
using System.Web.Mvc;
using Newtonsoft.Json;
using NewTravelAdminMVC.Models;

namespace NewTravelAdminMVC.Controllers
{
    [Authorize]
    public class StoresController : Controller
    {

        public async Task<ActionResult> Index()
        {
            var store = await GeStoresAsync();
            return View(store);
        }

        public async Task<ActionResult> Details(Guid id)
        {
            var v = await GetStockByIdAsync(id);
            return View(v);
        }

        public ActionResult Create()
        {
            return View();
        }

        [HttpPost]
        public ActionResult Create(Store store)
        {
            try
            {
                InsertNewStore(store);
                return RedirectToAction("Index");
            }
            catch
            {
                return View();
            }
        }

        public async Task<ActionResult> Edit(Guid id)
        {
            var store = await GetStoreByIdAsync(id);
            return View(store);
        }

        [HttpPost]
        public ActionResult Edit(Guid id, Store store)
        {
            try
            {
                if (ModelState.IsValid)
                {
                    UpdateStoreById(store);
                    return RedirectToAction("Index");
                }                
            }
            catch
            {
                return View();
            }
            return View();
        }


        #region API Calls Methods

        public async Task<List<Store>> GeStoresAsync()
        {
            using (HttpClient httpClient = new HttpClient())
            {                
                var response = await httpClient.GetStringAsync(WebAddress.StoreAddress);
                return JsonConvert.DeserializeObject<List<Store>>(response);                 
            }
        }

        public async Task<Store> GetStoreByIdAsync(Guid id)
        {
            using (HttpClient httpClient = new HttpClient())
            {
                var address = WebAddress.StoreAddress + "/" + id.ToString();
                var response = await httpClient.GetStringAsync(address);
                return JsonConvert.DeserializeObject<Store>(response);
            }
        }

        public HttpResponseMessage InsertNewStore(Store store)
        {
            var address = WebAddress.StoreAddress;
            HttpClient client = new HttpClient();
            return client.PostAsJsonAsync<Store>(address, store).Result;
        }

        public HttpResponseMessage UpdateStoreById(Store store)
        {
            var address = WebAddress.StoreAddress + "/" + store.StoreId.ToString();
            HttpClient client = new HttpClient();
            return client.PutAsJsonAsync<Store>(address, store).Result;
        }

        public async Task<List<Stock>> GetStockByIdAsync(Guid id)
        {
            using (HttpClient httpClient = new HttpClient())
            {
                var address = WebAddress.StocksAddress + "/" + id;
                var response = await httpClient.GetStringAsync(address);
                return JsonConvert.DeserializeObject<List<Stock>>(response);
            }
        }

        #endregion
    }
}
