﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net.Http;
using System.Threading.Tasks;
using System.Web;
using System.Web.Mvc;
using Newtonsoft.Json;
using NewTravelAdminMVC.Models;

namespace NewTravelAdminMVC.Controllers
{
    [Authorize]
    public class VehiclesController : Controller
    {

        public async Task<ActionResult> Index()
        {
            var s = await GetVehiclesAsync();
            return View(s);
        }

        public ActionResult Details(int id)
        {
            return View();
        }

        public async Task<ActionResult> Create()
        {
            var stores = await GetStoresAsync();
            var activeStores = stores.Where(m => m.Active == true).ToList();
            ViewBag.StoreId = new SelectList(activeStores, "StoreId", "Name");

            var categories = await GetVehicleCategoriesAsync();            
            var activeCategories = categories.Where(m => m.Active == true).ToList();
            ViewBag.vehicleCategoryId = new SelectList(activeCategories, "VehicleCategoryId", "Name");

            return View();
        }

        [HttpPost]
        public ActionResult Create(Vehicle vehicle)
        {
            try
            {
                if (ModelState.IsValid)
                {
                    var prova = InsertNewVehicle(vehicle);
                    Task.WaitAll(prova);
                    return RedirectToAction("Index");
                }
            }
            catch
            {
                return View();
            }
            return View();
        }

        public async Task<ActionResult> Edit(Guid id)
        {
            var vehicle = await GetVehicleByIdAsync(id);

            var stores = await GetStoresAsync();
            var activeStores = stores.Where(m => m.Active == true).ToList();
            ViewBag.StoreId = new SelectList(activeStores, "StoreId", "Name", vehicle.StoreId);

            var categories = await GetVehicleCategoriesAsync();
            var activeCategories = categories.Where(m => m.Active == true).ToList();
            ViewBag.vehicleCategoryId = new SelectList(activeCategories, "VehicleCategoryId", "Name", vehicle.VehicleCategoryId);
            
            return View(vehicle);    
        }

        [HttpPost]
        public ActionResult Edit(Vehicle vehicle)
        {
            try
            {
                if (ModelState.IsValid)
                {
                    var vav = UpdateVehicleById(vehicle);
                    Task.WaitAll(vav);
                    return RedirectToAction("Index");
                }
            }
            catch
            {
                return View();
            }
            return View();
        }

        #region API Calls Methods


      


        public async Task<List<Vehicle>> GetVehiclesAsync()
        {
            using (HttpClient httpClient = new HttpClient())
            {
                return JsonConvert.DeserializeObject<List<Vehicle>>(
                 await httpClient.GetStringAsync(WebAddress.VehicleAddress));
            }
        }

        public async Task<Vehicle> GetVehicleByIdAsync(Guid id)
        {
            using (HttpClient httpClient = new HttpClient())
            {
                var address = WebAddress.VehicleAddress + "/" + id.ToString();
                var JsonVehicle = await httpClient.GetStringAsync(address);
                return JsonConvert.DeserializeObject<Vehicle>(JsonVehicle);
            }
        }

        public Task<HttpResponseMessage> InsertNewVehicle(Vehicle vehicle)
        {
            var address = WebAddress.VehicleAddress;
            HttpClient client = new HttpClient();
            return client.PostAsJsonAsync<Vehicle>(address, vehicle);

        }

        public Task<HttpResponseMessage> UpdateVehicleById(Vehicle vehicle)
        {
            var address = WebAddress.VehicleAddress + "/" + vehicle.VehicleId.ToString();
            HttpClient client = new HttpClient();
            return client.PutAsJsonAsync<Vehicle>(address, vehicle);
        }



        public async Task<List<VehicleCategory>> GetVehicleCategoriesAsync()
        {
            using (HttpClient httpClient = new HttpClient())
            {
                return JsonConvert.DeserializeObject<List<VehicleCategory>>(
                 await httpClient.GetStringAsync(WebAddress.VehicleCategoryAddress));
            }
        }

        public async Task<List<Store>> GetStoresAsync()
        {
            using (HttpClient httpClient = new HttpClient())
            {
                var stores = await httpClient.GetStringAsync(WebAddress.StoreAddress);
                return JsonConvert.DeserializeObject<List<Store>>(stores);
            }
        }

        #endregion
       
    }
}
