﻿using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;
using System.Linq;
using System.Web;

namespace NewTravelAdminMVC.Models
{
    public class Employee
    {

        [Key]
        [DatabaseGeneratedAttribute(DatabaseGeneratedOption.Identity)]
        public Guid EmployeeId { get; set; }

        [Required]
        [StringLength(50, ErrorMessage = "El {0} ha de ser més petit de {1} caràcters")]
        [Display(Name = "Nom")]
        public string Name { get; set; }

        [Required]
        [StringLength(70, ErrorMessage = "El {0} ha de ser més petit de {1} caràcters")]
        [Display(Name = "Cognoms")]
        public string Surname { get; set; }

        [Required]
        [StringLength(20, ErrorMessage = "El {0} ha de ser més petit de {1} caràcters")]
        [Display(Name = "N.I.F.")]
        public string Nif { get; set; }

        [DataType(DataType.Date)]
        [DisplayFormat(DataFormatString = "{0:dd/MM/yyyy}", ApplyFormatInEditMode = true)]
        [Display(Name = "D. Naixement")]
        public DateTime BirthDate { get; set; }

        [Required(ErrorMessage = "Cal introduir un correu electrònic")]
        [DataType(DataType.EmailAddress)]
        [Display(Name = "Correu electrònic")]
        public string Email { get; set; }

        [Required(ErrorMessage = "Cal introduir una contrasenya")]
        [StringLength(100, ErrorMessage = "La {0} ha de tenir com a mínim {2} caràcters de longitud i un màxim de {1}.", MinimumLength = 6)]
        [DataType(DataType.Password)]
        [Display(Name = "Contrasenya")]
        [NotMapped]
        public string Password { get; set; }

        [Display(Name = "Actiu")]
        public bool ActiveUser { get; set; }



        public virtual Driver Driver { get; set; }

        [Display(Name = "Perfil")]
        public int Profile { get; set; }

        [NotMapped]
        public bool EditEmployee { get; set; }


        //private static void UpdateVehicleCategories(Employee employee)
        //{
        //    List<Guid> guids = new List<Guid>();

        //    if (employee.Driver.VehicleCategories != null)
        //    {
        //        foreach (var v in employee.Driver.VehicleCategories)
        //            guids.Add(v.VehicleCategoryId);
        //    }

        //    SqlConnection oConn = new SqlConnection(
        //     ConfigurationManager.ConnectionStrings["DefaultConnection1"].ConnectionString);

        //    SqlCommand oComm = new SqlCommand(
        //        "DELETE FROM DriverCategories WHERE DriverId = @DriverId", oConn);

        //    oComm.Parameters.AddWithValue("@DriverId", employee.EmployeeId);
        //    oConn.Open();
        //    oComm.ExecuteNonQuery();

        //    if (employee.Driver.VehicleCategories != null && employee.Profile > 2 && employee.Profile < 8)
        //    {
        //        oComm.Parameters.Clear();
        //        oComm.CommandText = "INSERT INTO DriverCategories VALUES (@DriverId, @VehicleCategoryId)";
        //        oComm.Parameters.AddWithValue("@DriverId", employee.EmployeeId);
        //        foreach (Guid id in guids)
        //        {
        //            if (!oComm.Parameters.Contains("@vehicleCategoryId"))
        //                oComm.Parameters.AddWithValue("@vehicleCategoryId", id);
        //            else
        //                oComm.Parameters["@vehicleCategoryId"].Value = id;
        //            oComm.ExecuteNonQuery();
        //        }
        //    }
        //    oConn.Close();

        //}

        //public static void updateDriver(Employee employee)
        //{
        //    using (SqlConnection oConn = new SqlConnection(
        //        ConfigurationManager.ConnectionStrings["DefaultConnection1"].ConnectionString))
        //    {
        //        try
        //        {
        //            SqlCommand oComm = new SqlCommand(
        //                "DELETE FROM Drivers WHERE DriverId =@DriverId", oConn);
        //            oComm.Parameters.AddWithValue("@DriverId", employee.EmployeeId);
        //            oConn.Open();
        //            oComm.ExecuteNonQuery();

        //            if (employee.Profile > 2 && employee.Profile < 8)
        //            {
        //                string licenseId = "";
        //                if (employee.Driver != null && employee.Driver.LicenseId != null)
        //                    licenseId = employee.Driver.LicenseId;

        //                bool activeDriver = false;
        //                if (employee.Driver != null && employee.Driver.Active == true) //&& employee.Driver.Active != null
        //                    activeDriver = true;

        //                oComm.Parameters.Clear();
        //                oComm.CommandText = "INSERT INTO Drivers(DriverId, LicenseID, Active) " +
        //                    "VALUES (@DriverId, @LicenseId, @Active)";
        //                oComm.Parameters.AddWithValue("@DriverId", employee.EmployeeId);
        //                oComm.Parameters.AddWithValue("@LicenseId", licenseId);
        //                oComm.Parameters.AddWithValue("@Active", activeDriver);
        //                oComm.ExecuteNonQuery();
        //            }
        //            oConn.Close();
        //        }
        //        catch (Exception ex)
        //        {
        //            var ss = ex.Message;
        //        }

        //    }

        //}




    }
}