namespace NewTravelWebAPI.Migrations
{
    using System;
    using System.Data.Entity.Migrations;
    
    public partial class InitialCreate : DbMigration
    {
        public override void Up()
        {
            CreateTable(
                "dbo.Employees",
                c => new
                    {
                        EmployeeId = c.Guid(nullable: false),
                        Name = c.String(nullable: false, maxLength: 50),
                        Surname = c.String(nullable: false, maxLength: 70),
                        Nif = c.String(nullable: false, maxLength: 20),
                        BirthDate = c.DateTime(nullable: false),
                        Email = c.String(nullable: false),
                        Password = c.String(nullable: false, maxLength: 100),
                        ActiveUser = c.Boolean(nullable: false),
                        Profile = c.Int(nullable: false),
                    })
                .PrimaryKey(t => t.EmployeeId);
            
            CreateTable(
                "dbo.Drivers",
                c => new
                    {
                        DriverId = c.Guid(nullable: false),
                        LicenseId = c.String(),
                        Active = c.Boolean(nullable: false),
                        PreferedVehicleId = c.Guid(),
                    })
                .PrimaryKey(t => t.DriverId)
                .ForeignKey("dbo.Employees", t => t.DriverId)
                .Index(t => t.DriverId);
            
            CreateTable(
                "dbo.VehicleCategories",
                c => new
                    {
                        VehicleCategoryId = c.Guid(nullable: false),
                        Name = c.String(nullable: false),
                        Active = c.Boolean(nullable: false),
                    })
                .PrimaryKey(t => t.VehicleCategoryId);
            
            CreateTable(
                "dbo.Vehicles",
                c => new
                    {
                        VehicleId = c.Guid(nullable: false),
                        Brand = c.String(maxLength: 50),
                        Model = c.String(maxLength: 50),
                        Plate = c.String(maxLength: 20),
                        Refrigerated = c.Boolean(nullable: false),
                        Active = c.Boolean(nullable: false),
                        MaxWidth = c.Int(nullable: false),
                        MaxHeight = c.Int(nullable: false),
                        MaxDepth = c.Int(nullable: false),
                        MaxWeight = c.Int(nullable: false),
                        VehicleCategoryId = c.Guid(nullable: false),
                        StoreId = c.Guid(nullable: false),
                    })
                .PrimaryKey(t => t.VehicleId)
                .ForeignKey("dbo.VehicleCategories", t => t.VehicleCategoryId, cascadeDelete: true)
                .ForeignKey("dbo.Stores", t => t.StoreId, cascadeDelete: true)
                .Index(t => t.VehicleCategoryId)
                .Index(t => t.StoreId);
            
            CreateTable(
                "dbo.Stores",
                c => new
                    {
                        StoreId = c.Guid(nullable: false),
                        Name = c.String(nullable: false, maxLength: 70),
                        Address = c.String(nullable: false, maxLength: 100),
                        City = c.String(nullable: false, maxLength: 30),
                        Country = c.String(nullable: false, maxLength: 30),
                        Latitude = c.String(),
                        Longitude = c.String(),
                        Active = c.Boolean(nullable: false),
                    })
                .PrimaryKey(t => t.StoreId);
            
            CreateTable(
                "dbo.Stocks",
                c => new
                    {
                        StoreId = c.Guid(nullable: false),
                        ProductId = c.Guid(nullable: false),
                        Items = c.Int(nullable: false),
                    })
                .PrimaryKey(t => new { t.StoreId, t.ProductId })
                .ForeignKey("dbo.Stores", t => t.StoreId, cascadeDelete: true)
                .ForeignKey("dbo.Products", t => t.ProductId, cascadeDelete: true)
                .Index(t => t.StoreId)
                .Index(t => t.ProductId);
            
            CreateTable(
                "dbo.Products",
                c => new
                    {
                        ProductId = c.Guid(nullable: false),
                        Name = c.String(nullable: false, maxLength: 100),
                        Width = c.Int(nullable: false),
                        Height = c.Int(nullable: false),
                        Depth = c.Int(nullable: false),
                        Weight = c.Int(nullable: false),
                        UnitPrice = c.Double(nullable: false),
                        Refrigerated = c.Boolean(nullable: false),
                        Active = c.Boolean(nullable: false),
                    })
                .PrimaryKey(t => t.ProductId);
            
            CreateTable(
                "dbo.Carts",
                c => new
                    {
                        CartId = c.Guid(nullable: false),
                        CustomerId = c.Guid(nullable: false),
                        ProductId = c.Guid(nullable: false),
                        Quantity = c.Int(nullable: false),
                        UnitPrice = c.Double(nullable: false),
                        Name = c.String(),
                    })
                .PrimaryKey(t => t.CartId)
                .ForeignKey("dbo.Customers", t => t.CustomerId, cascadeDelete: true)
                .ForeignKey("dbo.Products", t => t.ProductId, cascadeDelete: true)
                .Index(t => t.CustomerId)
                .Index(t => t.ProductId);
            
            CreateTable(
                "dbo.Customers",
                c => new
                    {
                        CustomerId = c.Guid(nullable: false),
                        NifCif = c.String(),
                        Name = c.String(),
                        Address = c.String(),
                        City = c.String(),
                        Country = c.String(),
                        Email = c.String(),
                        Password = c.String(),
                        CCC = c.String(),
                        Latitude = c.String(),
                        Longitude = c.String(),
                        Active = c.Boolean(nullable: false),
                    })
                .PrimaryKey(t => t.CustomerId);
            
            CreateTable(
                "dbo.Orders",
                c => new
                    {
                        OrderId = c.Guid(nullable: false),
                        CustomerId = c.Guid(nullable: false),
                        Date = c.DateTime(nullable: false),
                        EstimatedDelivery = c.DateTime(),
                        Delivery = c.DateTime(),
                        TotalAmount = c.Double(nullable: false),
                        StoreId = c.Guid(),
                    })
                .PrimaryKey(t => t.OrderId)
                .ForeignKey("dbo.Customers", t => t.CustomerId, cascadeDelete: true)
                .ForeignKey("dbo.Stores", t => t.StoreId)
                .Index(t => t.CustomerId)
                .Index(t => t.StoreId);
            
            CreateTable(
                "dbo.OrderDetails",
                c => new
                    {
                        OrderDetailId = c.Guid(nullable: false),
                        OrderId = c.Guid(nullable: false),
                        ProductId = c.Guid(nullable: false),
                        Quantity = c.Int(nullable: false),
                        UnitPrice = c.Double(nullable: false),
                        StoreId = c.Guid(),
                    })
                .PrimaryKey(t => t.OrderDetailId)
                .ForeignKey("dbo.Orders", t => t.OrderId, cascadeDelete: true)
                .ForeignKey("dbo.Products", t => t.ProductId, cascadeDelete: true)
                .Index(t => t.OrderId)
                .Index(t => t.ProductId);
            
            CreateTable(
                "dbo.DriverVehicles",
                c => new
                    {
                        DriverVehicleId = c.Guid(nullable: false),
                        DriverId = c.Guid(nullable: false),
                        VehicleId = c.Guid(nullable: false),
                        Date = c.DateTime(nullable: false),
                    })
                .PrimaryKey(t => t.DriverVehicleId)
                .ForeignKey("dbo.Drivers", t => t.DriverId, cascadeDelete: true)
                .ForeignKey("dbo.Vehicles", t => t.VehicleId, cascadeDelete: true)
                .Index(t => t.DriverId)
                .Index(t => t.VehicleId);
            
            CreateTable(
                "dbo.DriverCategories",
                c => new
                    {
                        DriverId = c.Guid(nullable: false),
                        VehicleCategoryId = c.Guid(nullable: false),
                    })
                .PrimaryKey(t => new { t.DriverId, t.VehicleCategoryId })
                .ForeignKey("dbo.Drivers", t => t.DriverId, cascadeDelete: true)
                .ForeignKey("dbo.VehicleCategories", t => t.VehicleCategoryId, cascadeDelete: true)
                .Index(t => t.DriverId)
                .Index(t => t.VehicleCategoryId);
            
        }
        
        public override void Down()
        {
            DropIndex("dbo.DriverCategories", new[] { "VehicleCategoryId" });
            DropIndex("dbo.DriverCategories", new[] { "DriverId" });
            DropIndex("dbo.DriverVehicles", new[] { "VehicleId" });
            DropIndex("dbo.DriverVehicles", new[] { "DriverId" });
            DropIndex("dbo.OrderDetails", new[] { "ProductId" });
            DropIndex("dbo.OrderDetails", new[] { "OrderId" });
            DropIndex("dbo.Orders", new[] { "StoreId" });
            DropIndex("dbo.Orders", new[] { "CustomerId" });
            DropIndex("dbo.Carts", new[] { "ProductId" });
            DropIndex("dbo.Carts", new[] { "CustomerId" });
            DropIndex("dbo.Stocks", new[] { "ProductId" });
            DropIndex("dbo.Stocks", new[] { "StoreId" });
            DropIndex("dbo.Vehicles", new[] { "StoreId" });
            DropIndex("dbo.Vehicles", new[] { "VehicleCategoryId" });
            DropIndex("dbo.Drivers", new[] { "DriverId" });
            DropForeignKey("dbo.DriverCategories", "VehicleCategoryId", "dbo.VehicleCategories");
            DropForeignKey("dbo.DriverCategories", "DriverId", "dbo.Drivers");
            DropForeignKey("dbo.DriverVehicles", "VehicleId", "dbo.Vehicles");
            DropForeignKey("dbo.DriverVehicles", "DriverId", "dbo.Drivers");
            DropForeignKey("dbo.OrderDetails", "ProductId", "dbo.Products");
            DropForeignKey("dbo.OrderDetails", "OrderId", "dbo.Orders");
            DropForeignKey("dbo.Orders", "StoreId", "dbo.Stores");
            DropForeignKey("dbo.Orders", "CustomerId", "dbo.Customers");
            DropForeignKey("dbo.Carts", "ProductId", "dbo.Products");
            DropForeignKey("dbo.Carts", "CustomerId", "dbo.Customers");
            DropForeignKey("dbo.Stocks", "ProductId", "dbo.Products");
            DropForeignKey("dbo.Stocks", "StoreId", "dbo.Stores");
            DropForeignKey("dbo.Vehicles", "StoreId", "dbo.Stores");
            DropForeignKey("dbo.Vehicles", "VehicleCategoryId", "dbo.VehicleCategories");
            DropForeignKey("dbo.Drivers", "DriverId", "dbo.Employees");
            DropTable("dbo.DriverCategories");
            DropTable("dbo.DriverVehicles");
            DropTable("dbo.OrderDetails");
            DropTable("dbo.Orders");
            DropTable("dbo.Customers");
            DropTable("dbo.Carts");
            DropTable("dbo.Products");
            DropTable("dbo.Stocks");
            DropTable("dbo.Stores");
            DropTable("dbo.Vehicles");
            DropTable("dbo.VehicleCategories");
            DropTable("dbo.Drivers");
            DropTable("dbo.Employees");
        }
    }
}
