﻿using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations.Schema;
using System.Data.Entity;
using System.Linq;
using System.Web;

namespace NewTravelWebAPI.Models
{
    public class DbContextAPI : DbContext
    {
        public DbSet<Employee> Employees { get; set; }
        public DbSet<Driver> Drivers { get; set; }



        public DbSet<Store> Stores { get; set; }
        public DbSet<Product> Products { get; set; }
        public DbSet<Stock> Stocks { get; set; }
        public DbSet<Vehicle> Vehicles { get; set; }
        public DbSet<VehicleCategory> VehicleCategories { get; set; }


        public DbSet<Cart> Carts { get; set; }
        public DbSet<Order> Orders { get; set; }
        public DbSet<OrderDetail> OrderDetails { get; set; }
                      
        public DbSet<Customer> Customers { get; set; }

        public DbSet<DriverVehicle> DriverVehicles { get; set; }


        public DbSet<TransportRoute> TransportRoutes { get; set; }


        protected override void OnModelCreating(DbModelBuilder modelBuilder)
        {
            modelBuilder.Entity<Driver>()
               .HasKey(e => e.DriverId);


            modelBuilder.Entity<Driver>()
                .Property(e => e.DriverId)
                .HasDatabaseGeneratedOption(DatabaseGeneratedOption.None);

            modelBuilder.Entity<Driver>()
                .HasRequired(e => e.Employee)
                .WithRequiredDependent(s => s.Driver);


            modelBuilder.Entity<Driver>().HasMany<VehicleCategory>(s => s.VehicleCategories).WithMany(c => c.Drivers).Map(c =>
            {
                c.MapLeftKey("DriverId");
                c.MapRightKey("VehicleCategoryId");
                c.ToTable("DriverCategories");

            });



            base.OnModelCreating(modelBuilder);

            //base.OnModelCreating(modelBuilder);
        }
    }
}