﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;

namespace NewTravelWebAPI.Models
{
    public class DriverVehicle
    {

        public Guid DriverVehicleId { get; set; }

        public Guid DriverId { get; set; }
        public Driver Driver { get; set; }

        public Guid VehicleId { get; set; }
        public Vehicle Vehicle { get; set; }

        public DateTime Date { get; set; }

   

        public static DriverVehicleAssignModel GenerateDriverVehicleList(DbContextAPI _db)
        {

            DriverVehicleAssignModel dvm = new DriverVehicleAssignModel();

            List<DriverVehicle> DriverVehicleAssigns = new List<DriverVehicle>();

            //1. Consultem els Conductors Disponibles i quins tipus de vehicles poden conduir
            var AvailableDrivers = _db.Drivers.Include("VehicleCategories").Where(m => m.Active == true).ToList();

            //2. Obtenim els Vehicles i el Tipus de vehicles al que corresponen                     
            var AvailableVehicles = _db.Vehicles.Where(m => m.Active == true).ToList();

            //3. Creem la llista de vehicles disponibles
            DriverVehicleAssigns = CreateDriverVehicleList(AvailableDrivers, AvailableVehicles,dvm);

            //4. Afegim la llista a la base de dades => No ho fem directament, demanem autorització usuari
            InsertDriverVehiclesToDatabase(DriverVehicleAssigns, _db);

            return dvm;
        }

        private static List<DriverVehicle> CreateDriverVehicleList(List<Driver> AvailableDrivers, List<Vehicle> AvailableVehicles, DriverVehicleAssignModel dvm)
        {
            List<DriverVehicle> DriverVehicles = new List<DriverVehicle>();
            while (AvailableDrivers.Count(m => m.Assigned == false) > 0 && AvailableVehicles.Count(n => n.Assigned == false) > 0)
            {
                foreach (var itemVehicle in AvailableVehicles)
                {
                    if (itemVehicle.Assigned)
                        continue;

                    var PosibleDrivers = AvailableDrivers.Where(m => m.VehicleCategories.Contains(itemVehicle.VehicleCategory) && m.Assigned == false).ToList();

                    if (PosibleDrivers.Count == 1)
                        DriverVehicles.Add(AddDriverVehicleToList(PosibleDrivers[0], itemVehicle));
                    else if (PosibleDrivers.Count > 1)
                    {
                        Driver driver = null;

                        foreach (Driver dr in PosibleDrivers)
                        {
                            if (driver == null)
                                driver = dr;
                            else
                            {
                                if (dr.VehicleCategories.Count < driver.VehicleCategories.Count)
                                    driver = dr;
                            }
                        }
                        DriverVehicles.Add(AddDriverVehicleToList(driver, itemVehicle));
                    }
                    else
                    {
                        itemVehicle.Assigned = true;
                        itemVehicle.AssignedError = true;
                    }
                }
            }
            dvm.DriverVehicles = DriverVehicles;
            foreach (var v in AvailableDrivers)
            {
                if (v.Assigned == false)
                {
                    if (dvm.Drivers == null)
                        dvm.Drivers = new List<Driver>();
                    dvm.Drivers.Add(v);
                }
            }
            foreach (var v in AvailableVehicles)
            {
                if (v.AssignedError == true)
                {
                    if (dvm.Vehicles == null)
                        dvm.Vehicles = new List<Vehicle>();
                    dvm.Vehicles.Add(v);
                }
            }

            return DriverVehicles;
        }

        private static DriverVehicle AddDriverVehicleToList(Driver driver, Vehicle vehicle)
        {
            vehicle.Assigned = true;
            driver.Assigned = true;

            DriverVehicle DriverVehicleAssign = new DriverVehicle();
            DriverVehicleAssign.DriverVehicleId = Guid.NewGuid();
            DriverVehicleAssign.Driver = driver;
            DriverVehicleAssign.Vehicle = vehicle;
            DriverVehicleAssign.Date = DateTime.Now.Date;
            return DriverVehicleAssign;

        }

        public static void InsertDriverVehiclesToDatabase(List<DriverVehicle> DriverVehicleAssigns, DbContextAPI _db)
        {
            foreach (var v in DriverVehicleAssigns)
            {
                _db.DriverVehicles.Add(v);
            }
            _db.SaveChanges();
        }

        
        
    }
    
}